@@ -25,7 +25,9 @@ class Diagram(blockdiag.elements.Diagram):
         super(Diagram, self).__init__()
 
         self.orientation = 'portrait'
-        self.span_height = 120
+        self.node_width = 104
+        self.span_width = 48
+        self.span_height = 104
         self.groups = []
         self.networks = []
 
@@ -56,6 +58,8 @@ class Network(blockdiag.elements.NodeGroup):
         super(Network, self).__init__(id)
 
         self.address = None
+        self.width = 0
+        self.height = 0
 
     @property
     def display_label(self):
